@@ -17,7 +17,7 @@ import requests
 from plugin import Plugin, PluginManager
 
 from localstack import config
-from localstack.config import dirs, is_env_true
+from localstack.config import dirs
 from localstack.constants import (
     DEFAULT_SERVICE_PORTS,
     DYNAMODB_JAR_URL,
@@ -42,6 +42,7 @@ from localstack.utils.common import (
     mkdir,
     new_tmp_file,
     parallelize,
+    replace_in_file,
     retry,
     rm_rf,
     run,
@@ -60,6 +61,7 @@ INSTALL_DIR_KCL = "%s/amazon-kinesis-client" % dirs.static_libs
 INSTALL_DIR_STEPFUNCTIONS = "%s/stepfunctions" % dirs.static_libs
 INSTALL_DIR_KMS = "%s/kms" % dirs.static_libs
 INSTALL_DIR_ELASTICMQ = "%s/elasticmq" % dirs.static_libs
+INSTALL_DIR_KINESIS_MOCK = os.path.join(dirs.static_libs, "kinesis-mock")
 INSTALL_PATH_LOCALSTACK_FAT_JAR = "%s/localstack-utils-fat.jar" % dirs.static_libs
 INSTALL_PATH_DDB_JAR = os.path.join(INSTALL_DIR_DDB, "DynamoDBLocal.jar")
 INSTALL_PATH_KCL_JAR = os.path.join(INSTALL_DIR_KCL, "aws-java-sdk-sts.jar")
@@ -67,7 +69,6 @@ INSTALL_PATH_STEPFUNCTIONS_JAR = os.path.join(INSTALL_DIR_STEPFUNCTIONS, "StepFu
 INSTALL_PATH_KMS_BINARY_PATTERN = os.path.join(INSTALL_DIR_KMS, "local-kms.<arch>.bin")
 INSTALL_PATH_ELASTICMQ_JAR = os.path.join(INSTALL_DIR_ELASTICMQ, "elasticmq-server.jar")
 INSTALL_PATH_KINESALITE_CLI = os.path.join(INSTALL_DIR_NPM, "kinesalite", "cli.js")
-INSTALL_PATH_KINESIS_MOCK = os.path.join(dirs.static_libs, "kinesis-mock")
 URL_LOCALSTACK_FAT_JAR = (
     "https://repo1.maven.org/maven2/"
     + "cloud/localstack/localstack-utils/{v}/localstack-utils-{v}-fat.jar"
@@ -77,7 +78,7 @@ MARKER_FILE_LIGHT_VERSION = "%s/.light-version" % dirs.static_libs
 IMAGE_NAME_SFN_LOCAL = "amazon/aws-stepfunctions-local"
 ARTIFACTS_REPO = "https://github.com/localstack/localstack-artifacts"
 SFN_PATCH_URL_PREFIX = (
-    f"{ARTIFACTS_REPO}/raw/047cc6dcd2e31f5ff3ec52d293c61b875f606958/stepfunctions-local-patch"
+    f"{ARTIFACTS_REPO}/raw/a4adc8f4da9c7ec0d93b50ca5b73dd14df791c0e/stepfunctions-local-patch"
 )
 SFN_PATCH_CLASS1 = "com/amazonaws/stepfunctions/local/runtime/Config.class"
 SFN_PATCH_CLASS2 = (
@@ -85,8 +86,15 @@ SFN_PATCH_CLASS2 = (
 )
 SFN_PATCH_CLASS_STARTER = "cloud/localstack/StepFunctionsStarter.class"
 SFN_PATCH_CLASS_REGION = "cloud/localstack/RegionAspect.class"
+SFN_PATCH_CLASS_ASYNC2SERVICEAPI = "cloud/localstack/Async2ServiceApi.class"
+SFN_PATCH_CLASS_DESCRIBEEXECUTIONPARSED = "cloud/localstack/DescribeExecutionParsed.class"
 SFN_PATCH_FILE_METAINF = "META-INF/aop.xml"
 
+SFN_AWS_SDK_URL_PREFIX = (
+    f"{ARTIFACTS_REPO}/raw/a4adc8f4da9c7ec0d93b50ca5b73dd14df791c0e/stepfunctions-internal-awssdk"
+)
+SFN_AWS_SDK_LAMBDA_ZIP_FILE = f"{SFN_AWS_SDK_URL_PREFIX}/awssdk.zip"
+
 # additional JAR libs required for multi-region and persistence (PRO only) support
 MAVEN_REPO = "https://repo1.maven.org/maven2"
 URL_ASPECTJRT = f"{MAVEN_REPO}/org/aspectj/aspectjrt/1.9.7/aspectjrt-1.9.7.jar"
@@ -296,31 +304,45 @@ def install_elasticmq():
 
 def install_kinesis():
     if config.KINESIS_PROVIDER == "kinesalite":
-        return install_kinesalite()
-    elif config.KINESIS_PROVIDER == "kinesis-mock":
-        return install_kinesis_mock()
-    else:
-        raise ValueError("unknown kinesis provider %s" % config.KINESIS_PROVIDER)
+        install_kinesalite()
+        return
+    if config.KINESIS_PROVIDER == "kinesis-mock":
+        is_installed, bin_path = get_is_kinesis_mock_installed()
+        if not is_installed:
+            install_kinesis_mock(bin_path)
+        return
+    raise ValueError("unknown kinesis provider %s" % config.KINESIS_PROVIDER)
+
+
+def _apply_patches_kinesalite():
+    files = [
+        "%s/kinesalite/validations/decreaseStreamRetentionPeriod.js",
+        "%s/kinesalite/validations/increaseStreamRetentionPeriod.js",
+    ]
+    for file_path in files:
+        file_path = file_path % INSTALL_DIR_NPM
+        replace_in_file("lessThanOrEqual: 168", "lessThanOrEqual: 8760", file_path)
 
 
 def install_kinesalite():
     if not os.path.exists(INSTALL_PATH_KINESALITE_CLI):
         log_install_msg("Kinesis")
         run('cd "%s" && npm install' % MODULE_MAIN_PATH)
+        _apply_patches_kinesalite()
 
 
-def install_kinesis_mock():
-    target_dir = INSTALL_PATH_KINESIS_MOCK
-
+def get_is_kinesis_mock_installed() -> Tuple[bool, str]:
+    """
+    Checks the host system to see if kinesis mock is installed and where.
+    :returns: True if kinesis mock is installed (False otherwise) and the expected installation path
+    """
     machine = platform.machine().lower()
     system = platform.system().lower()
     version = platform.version().lower()
-
     is_probably_m1 = system == "darwin" and ("arm64" in version or "arm32" in version)
 
     LOG.debug("getting kinesis-mock for %s %s", system, machine)
-
-    if is_env_true("KINESIS_MOCK_FORCE_JAVA"):
+    if config.is_env_true("KINESIS_MOCK_FORCE_JAVA"):
         # sometimes the static binaries may have problems, and we want to fal back to Java
         bin_file = "kinesis-mock.jar"
     elif (machine == "x86_64" or machine == "amd64") and not is_probably_m1:
@@ -335,11 +357,14 @@ def install_kinesis_mock():
     else:
         bin_file = "kinesis-mock.jar"
 
-    bin_file_path = os.path.join(target_dir, bin_file)
+    bin_file_path = os.path.join(INSTALL_DIR_KINESIS_MOCK, bin_file)
     if os.path.exists(bin_file_path):
         LOG.debug("kinesis-mock found at %s", bin_file_path)
-        return bin_file_path
+        return True, bin_file_path
+    return False, bin_file_path
 
+
+def install_kinesis_mock(bin_file_path: str):
     response = requests.get(KINESIS_MOCK_RELEASE_URL)
     if not response.ok:
         raise ValueError(
@@ -348,22 +373,22 @@ def install_kinesis_mock():
 
     github_release = response.json()
     download_url = None
+    bin_file_name = os.path.basename(bin_file_path)
     for asset in github_release.get("assets", []):
         # find the correct binary in the release
-        if asset["name"] == bin_file:
+        if asset["name"] == bin_file_name:
             download_url = asset["browser_download_url"]
             break
-
     if download_url is None:
         raise ValueError(
-            "could not find required binary %s in release %s" % (bin_file, KINESIS_MOCK_RELEASE_URL)
+            "could not find required binary %s in release %s"
+            % (bin_file_name, KINESIS_MOCK_RELEASE_URL)
         )
 
-    mkdir(target_dir)
+    mkdir(INSTALL_DIR_KINESIS_MOCK)
     LOG.info("downloading kinesis-mock binary from %s", download_url)
     download(download_url, bin_file_path)
     chmod_r(bin_file_path, 0o777)
-    return bin_file_path
 
 
 def install_local_kms():
@@ -408,6 +433,8 @@ def install_stepfunctions_local():
         SFN_PATCH_CLASS2,
         SFN_PATCH_CLASS_REGION,
         SFN_PATCH_CLASS_STARTER,
+        SFN_PATCH_CLASS_ASYNC2SERVICEAPI,
+        SFN_PATCH_CLASS_DESCRIBEEXECUTIONPARSED,
         SFN_PATCH_FILE_METAINF,
     ]
     for patch_class in classes:
@@ -435,6 +462,11 @@ def install_stepfunctions_local():
         if not file_exists_not_empty(target):
             download(jar_url, target)
 
+    # download aws-sdk lambda handler
+    target = os.path.join(INSTALL_DIR_STEPFUNCTIONS, "localstack-internal-awssdk", "awssdk.zip")
+    if not file_exists_not_empty(target):
+        download(SFN_AWS_SDK_LAMBDA_ZIP_FILE, target)
+
 
 def add_file_to_jar(class_file, class_url, target_jar, base_dir=None):
     base_dir = base_dir or os.path.dirname(target_jar)
